@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ ExternalComposerPluginEditor::ExternalComposerPluginEditor(QObject *parent, cons
 {
 }
 
-ExternalComposerPluginEditor::~ExternalComposerPluginEditor()
-{
-}
+ExternalComposerPluginEditor::~ExternalComposerPluginEditor() = default;
 
 MessageComposer::PluginEditorInitInterface *ExternalComposerPluginEditor::createInterface(QObject *parent)
 {
