@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ InsertShorturlConfigureDialog::InsertShorturlConfigureDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
 }
 
-InsertShorturlConfigureDialog::~InsertShorturlConfigureDialog()
-{
-}
+InsertShorturlConfigureDialog::~InsertShorturlConfigureDialog() = default;
 
 void InsertShorturlConfigureDialog::accept()
 {
