@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ CheckBeforeSendPlugin::CheckBeforeSendPlugin(QObject *parent, const QList<QVaria
 {
 }
 
-CheckBeforeSendPlugin::~CheckBeforeSendPlugin()
-{
-}
+CheckBeforeSendPlugin::~CheckBeforeSendPlugin() = default;
 
 MessageComposer::PluginEditorCheckBeforeSendInterface *CheckBeforeSendPlugin::createInterface(QObject *parent)
 {
