@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -43,9 +43,7 @@ GrammarResultWidget::GrammarResultWidget(QWidget *parent)
     mainLayout->addWidget(mResult);
 }
 
-GrammarResultWidget::~GrammarResultWidget()
-{
-}
+GrammarResultWidget::~GrammarResultWidget() = default;
 
 void GrammarResultWidget::addExtraWidget()
 {
