@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -38,9 +38,7 @@ SelectAttachmentDialog::SelectAttachmentDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
 }
 
-SelectAttachmentDialog::~SelectAttachmentDialog()
-{
-}
+SelectAttachmentDialog::~SelectAttachmentDialog() = default;
 
 void SelectAttachmentDialog::setAttachmentPath(const QUrl &path)
 {
