@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ AdblockManagerTest::AdblockManagerTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-AdblockManagerTest::~AdblockManagerTest()
-{
-}
+AdblockManagerTest::~AdblockManagerTest() = default;
 
 void AdblockManagerTest::shouldHaveDefaultValue()
 {
